@@ -5,6 +5,7 @@ import time
 
 import numpy as np
 import torch
+from mgetool.tool import tt
 from sklearn import metrics
 from torch.nn import Module
 from torch.optim.lr_scheduler import MultiStepLR
@@ -135,7 +136,7 @@ class BaseLearning:
                 self.loss_method = torch.nn.MSELoss()
 
         else:
-            self.loss_method = loss_method()
+            self.loss_method = loss_method
         if self.milestones is None:
             self.milestones = [30, 50, 80]
         self.scheduler = MultiStepLR(self.optimizer, gamma=0.15, milestones=self.milestones)
@@ -170,6 +171,7 @@ class BaseLearning:
             epoch += start_epoch
             print("Try to run start from 'resumed epoch' {} to 'epoch' {}".format(start_epoch, epoch))
         for epochi in range(start_epoch, epoch):
+
             train_loader.reset()
 
             self._train(epochi)
@@ -218,15 +220,17 @@ class BaseLearning:
             self.optimizer.zero_grad()
 
             y_pred = self.model(*batch_x)
+
             lossi = self.loss_method(y_pred, batch_y)
 
-            losses.update(lossi.cpu().item(), batch_y.size(0))
+            losses.update(float(lossi.cpu().item()), batch_y.size(0))
+
             if self.clf is False:
-                mae_error = mae((y_pred.data.cpu()), batch_y)
+                mae_error = mae(y_pred.data.cpu(), batch_y.cpu())
                 mae_errors.update(mae_error, batch_y.size(0))
             else:
                 accuracy, precision, recall, fscore, auc_score = \
-                    class_eval(y_pred.data.cpu(), batch_y)
+                    class_eval(y_pred.data.cpu(), batch_y.cpu())
 
                 accuracies.update(accuracy, batch_y.size(0))
                 precisions.update(precision, batch_y.size(0))
@@ -234,13 +238,16 @@ class BaseLearning:
                 fscores.update(fscore, batch_y.size(0))
                 auc_scores.update(auc_score, batch_y.size(0))
 
+
             lossi.backward()
+
             self.optimizer.step()
             point = time.time()
 
+
             if m % self.print_freq == 0 and self.print_what in ["all","train"]:
                 if self.clf is False:
-                    print('Epoch: [{0}][{1}/{2}]\t'
+                    print('Train: [{0}][{1}/{2}]\t'
                           'Loss {loss.val:.4f} ({loss.avg:.4f})\t'
                           'MAE {mae_errors.val:.3f} ({mae_errors.avg:.3f})'
                           'Time {batch_time.val:.3f} ({batch_time.avg:.3f})\t'
@@ -248,7 +255,7 @@ class BaseLearning:
                         epochi, m, len(self.train_loader), loss=losses,
                         batch_time=batch_time, mae_errors=mae_errors))
                 else:
-                    print('Epoch: [{0}][{1}/{2}]\t'
+                    print('Train: [{0}][{1}/{2}]\t'
                           'Loss {loss.val:.4f} ({loss.avg:.4f})\t'
                           'Accu {accu.val:.3f} ({accu.avg:.3f})\t'
                           'Precision {prec.val:.3f} ({prec.avg:.3f})\t'
@@ -287,11 +294,11 @@ class BaseLearning:
             losses.update(lossi.cpu().item(), batch_y.size(0))
             if self.clf is False:
 
-                mae_error = mae((y_pred.data.cpu()), batch_y)
+                mae_error = mae((y_pred.data.cpu()), batch_y.cpu())
                 mae_errors.update(mae_error, batch_y.size(0))
             else:
                 accuracy, precision, recall, fscore, auc_score = \
-                    class_eval(y_pred.data.cpu(), batch_y)
+                    class_eval(y_pred.data.cpu(), batch_y.cpu())
 
                 accuracies.update(accuracy, batch_y.size(0))
                 precisions.update(precision, batch_y.size(0))
